.. Agilkia documentation master file, created by
   sphinx-quickstart on Mon Oct 21 15:25:16 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Agilkia!
===================================

Agilkia is a Python library for smart testing of web services and web sites.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   example
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
